@@ -8,6 +8,7 @@ from degiro_connector.trading.models.session_storage import (
 )
 from degiro_connector.trading.pb.trading_pb2 import (
     AccountOverview,
+    Agenda,
     CashAccountReport,
     CompanyProfile,
     CompanyRatios,
@@ -492,6 +493,25 @@ class Basic:
             logger=logger,
         )
 
+    def get_agenda(
+        self,
+        request: Agenda.Request,
+        session_id: str,
+        raw: bool = False,
+    ) -> Union[dict, Agenda]:
+        credentials = self._credentials
+        logger = self._logger
+        session = self._session_storage.session
+
+        return utilities.get_agenda(
+            request=request,
+            session_id=session_id,
+            credentials=credentials,
+            raw=raw,
+            session=session,
+            logger=logger,
+        )
+
 
 if __name__ == '__main__':
     # IMPORTATIONS
