@@ -8,6 +8,7 @@ import urllib3
 
 from degiro_connector.trading.constants.headers import Headers
 from degiro_connector.trading.pb.trading_pb2 import (
+    Agenda,
     AccountOverview,
     CompanyProfile,
     CashAccountReport,
@@ -1528,6 +1529,50 @@ def get_cash_account_report(
     return response
 
 
+def get_agenda(
+    request: Agenda.Request,
+    session_id: str,
+    credentials: Credentials,
+    raw: bool = False,
+    session: requests.Session = None,
+    logger: logging.Logger = None,
+) -> Union[dict, Agenda]:
+    if logger is None:
+        logger = build_logger()
+    if session is None:
+        session = build_session()
+
+    url = urls.AGENDA
+    params = payload_handler.agenda_request_to_api(
+        request=request,
+    )
+    params['intAccount'] = credentials.int_account
+    params['sessionId'] = session_id
+
+    req = requests.Request(method='GET', url=url, params=params)
+    prepped = session.prepare_request(req)
+    response_raw = None
+
+    try:
+        response_raw = session.send(prepped, verify=False)
+        response_dict = response_raw.json()
+
+        if raw is True:
+            response = response_dict
+        else:
+            response = payload_handler.agenda_to_grpc(
+                request=request,
+                payload=response_dict,
+            )
+    except Exception as e:
+        logger.fatal(response_raw.status_code)
+        logger.fatal(response_raw.text)
+        logger.fatal(e)
+        return False
+
+    return response
+
+
 if __name__ == '__main__':
     # IMPORTATIONS
     import logging
